pan-iot-security-python
=======================

``pan-iot-security-python`` is a Python package for the Palo Alto
Networks
`IoT Security API
<https://docs.paloaltonetworks.com/iot/iot-security-api-reference.html>`_.

It provides a Python3
`asyncio <https://docs.python.org/3/library/asyncio.html>`_
and non-asyncio
class and command line interface to the IoT Security RESTful API.

Documentation
-------------

- Rendered reStructuredText on GitHub:

  https://github.com/PaloAltoNetworks/pan-iot-security-python/tree/main/doc

Install ``pan-iot-security-python``
-----------------------------------

``pan-iot-security-python`` is available as a
`release
<https://github.com/PaloAltoNetworks/pan-iot-security-python/releases/>`_
on GitHub and as a
`package
<https://pypi.org/project/pan-iot-security-python/>`_
on PyPi.
